@@ -1,16 +1,12 @@
-/*
+/* 
 
 This file is part of netcdf-4, a netCDF-like interface for HDF5, or a
 HDF5 backend for netCDF, depending on your point of view.
 
-This file contains macros and prototyes relating to logging
-errors. Also it contains the functions nc_malloc, nc_calloc, and
-nc_free, which provide some simple memory checking for debug purposes
-only.
+This file contains macros and prototyes relating to logging errors.
 
-Copyright 1993-2005, University Corporation for Atmospheric
-Research. See COPYRIGHT file for copying and redistribution
-conditions.
+Copyright 1993, University Corporation for Atmospheric Research. See
+COPYRIGHT file for copying and redistribution conditions.
 
 */
 
@@ -22,9 +18,9 @@ conditions.
 #include <assert.h>
 #include "netcdf.h"
 
-void *nc_malloc(size_t size);
-void *nc_calloc(size_t nmemb, size_t size);
-void nc_free(void *ptr);
+#define nc_calloc calloc
+#define nc_malloc malloc
+#define nc_free free
 
 #ifdef LOGGING
 
@@ -51,24 +47,9 @@ retval = e; \
 goto exit; \
 } while (0) 
 
-
-/* Extra memory debugging can be turned on with the EXTRA_MEM_DEBUG
-   flag at compile. */
-#ifdef EXTRA_MEM_DEBUG
-#define MEM_DEBUG_MAX_BLOCKS (100000)
-typedef struct {
-   void *address;
-   size_t size;
-} NC_MEM_DEBUG_T;
-#endif
-
 #else
 
 /* These definitions will be used unless LOGGING is defined. */
-#define nc_calloc calloc
-#define nc_malloc malloc
-#define nc_free free
-
 #define LOG(e)
 #define BAIL(e) do { \
 retval = e; \
